/*
* @file    FT800_config.h
* @brief   configuration information for some TFTs and some pre-defined colors
* @version 2.0
* @date    2016-04-19
* @author  Rudolph Riedel
*/

#ifndef FT800_CONFIG_H_
#define FT800_CONFIG_H_

// switch over to FT81x
//#define FT_81X_ENABLE


// select the settings for the TFT attached

#define FT_VM800B35A
//#define FT_VM800B43A
//#define FT810CB_HY50HD
//#define ET07
//#define RVT70AQ



// VM800B35A: FT800 320x240 3.5" FTDI
#ifdef FT_VM800B35A
#define FT_VSYNC0	(0L)	// Tvf Vertical Front Porch
#define FT_VSYNC1	(2L)	// Tvf + Tvp Vertical Front Porch plus Vsync Pulse width
#define FT_VOFFSET	(13L)	// Tvf + Tvp + Tvb Number of non-visible lines (in lines)
#define FT_VCYCLE	(263L)	// Tv Total number of lines (visible and non-visible) (in lines)
#define FT_VSIZE	(240L)	// Tvd Number of visible lines (in lines) - display height
#define FT_HSYNC0	(0L)	// Thf Horizontal Front Porch
#define FT_HSYNC1	(10L)	// Thf + Thp Horizontal Front Porch plus Hsync Pulse width
#define FT_HOFFSET 	(70L)	// Thf + Thp + Thb Length of non-visible part of line (in PCLK cycles)
#define FT_HCYCLE 	(408L)	// Th Total length of line (visible and non-visible) (in PCLKs)
#define FT_HSIZE	(320L)	// Thd Length of visible part of line (in PCLKs) - display width
#define FT_PCLKPOL 	(0L)	// PCLK polarity (0 = rising edge, 1 = falling edge)
#define FT_SWIZZLE 	(2L)	// Defines the arrangement of the RGB pins of the FT800
#define FT_PCLK		(8L)	// 48MHz / REG_PCLK = PCLK frequency
#define FT_TOUCH_RZTHRESH (1200L)	// touch-sensitivity
#endif

// VM800B43A: FT800 480x272 4.3" FTDI
#ifdef FT_VM800B43A
#define FT_VSYNC0	(0L)
#define FT_VSYNC1	(10L)
#define FT_VOFFSET	(12L)
#define FT_VCYCLE	(292L)
#define FT_VSIZE	(272L) //display height
#define FT_HSYNC0	(0L)
#define FT_HSYNC1	(41L)
#define FT_HOFFSET 	(43L)
#define FT_HCYCLE 	(548L)
#define FT_HSIZE	(480L) //display width
#define FT_PCLKPOL 	(1L)
#define FT_SWIZZLE 	(0L)
#define FT_PCLK		(5L)
#define FT_TOUCH_RZTHRESH (1200L)	// touch-sensitivity
#endif

// FT810CB-HY50HD: FT810 800x480 5" HAOYU
#ifdef FT810CB_HY50HD
#define FT_VSYNC0	(0L) 	// Tvf Vertical Front Porch
#define FT_VSYNC1	(2L) 	// Tvf + Tvp Vertical Front Porch plus Vsync Pulse width
#define FT_VOFFSET	(13L) 	// Tvf + Tvp + Tvb Number of non-visible lines (in lines)
#define FT_VCYCLE	(525L)	// Tv Total number of lines (visible and non-visible) (in lines)
#define FT_VSIZE	(480L)	// Tvd Number of visible lines (in lines) - display height
#define FT_HSYNC0	(0L) 	// Thf Horizontal Front Porch
#define FT_HSYNC1	(20L)	// Thf + Thp Horizontal Front Porch plus Hsync Pulse width
#define FT_HOFFSET 	(64L) 	// Thf + Thp + Thb Length of non-visible part of line (in PCLK cycles)
#define FT_HCYCLE 	(952L) 	// Th Total length of line (visible and non-visible) (in PCLKs)
#define FT_HSIZE	(800L)	// Thd Length of visible part of line (in PCLKs) - display width
#define FT_PCLKPOL 	(1L)	// PCLK polarity (0 = rising edge, 1 = falling edge)
#define FT_SWIZZLE 	(0L)	// Defines the arrangement of the RGB pins of the FT800
#define FT_PCLK		(2L)	// 60MHz / REG_PCLK = PCLK frequency	30 MHz
#define FT_TOUCH_RZTHRESH (2000L)	// touch-sensitivity
#endif

#ifdef FT_800x480x
#define FT_VSYNC0	(0L) //(13L)	// Tvf Vertical Front Porch
#define FT_VSYNC1	(10L) //(16L)	// Tvf + Tvp Vertical Front Porch plus Vsync Pulse width
#define FT_VOFFSET	(35L) //(48L)	// Tvf + Tvp + Tvb Number of non-visible lines (in lines)
#define FT_VCYCLE	(516L)	// Tv Total number of lines (visible and non-visible) (in lines)
#define FT_VSIZE	(480L)	// Tvd Number of visible lines (in lines) - display height
#define FT_HSYNC0	(0L) //(40L)	// Thf Horizontal Front Porch
#define FT_HSYNC1	(88L)	// Thf + Thp Horizontal Front Porch plus Hsync Pulse width
#define FT_HOFFSET 	(169L) //(176L)	// Thf + Thp + Thb Length of non-visible part of line (in PCLK cycles)
#define FT_HCYCLE 	(969L) //(928L)	// Th Total length of line (visible and non-visible) (in PCLKs)
#define FT_HSIZE	(800L)	// Thd Length of visible part of line (in PCLKs) - display width
#define FT_PCLKPOL 	(1L)	// PCLK polarity (0 = rising edge, 1 = falling edge)
#define FT_SWIZZLE 	(0L)	// Defines the arrangement of the RGB pins of the FT800
#define FT_PCLK		(2L)	// 60MHz / REG_PCLK = PCLK frequency	30 MHz
#define FT_TOUCH_RZTHRESH (1200L)	// touch-sensitivity
#endif

// G-ET0700G0DM6 800x480 7" Glyn, untested
#ifdef ET07
#define FT_VSYNC0	(0L)	// Tvf Vertical Front Porch
#define FT_VSYNC1	(2L)	// Tvf + Tvp Vertical Front Porch plus Vsync Pulse width
#define FT_VOFFSET	(35L)	// Tvf + Tvp + Tvb Number of non-visible lines (in lines)
#define FT_VCYCLE	(525L)	// Tv Total number of lines (visible and non-visible) (in lines)
#define FT_VSIZE	(480L)	// Tvd Number of visible lines (in lines) - display height
#define FT_HSYNC0	(0L)	// Thf Horizontal Front Porch
#define FT_HSYNC1	(128L)	// Thf + Thp Horizontal Front Porch plus Hsync Pulse width
#define FT_HOFFSET 	(203L)	// Thf + Thp + Thb Length of non-visible part of line (in PCLK cycles)
#define FT_HCYCLE 	(1056L)	// Th Total length of line (visible and non-visible) (in PCLKs)
#define FT_HSIZE	(800L)	// Thd Length of visible part of line (in PCLKs) - display width
#define FT_PCLKPOL 	(1L)	// PCLK polarity (0 = rising edge, 1 = falling edge)
#define FT_SWIZZLE 	(0L)	// Defines the arrangement of the RGB pins of the FT800
#define FT_PCLK		(2L)	// 60MHz / REG_PCLK = PCLK frequency	30 MHz
#define FT_TOUCH_RZTHRESH (1200L)	// touch-sensitivity
#endif

// RVT70AQxxxxxx 800x480 7" Riverdi, various options, FT812/FT813, untested
#ifdef RVT70AQ
#define FT_VSYNC0	(0L)	// Tvf Vertical Front Porch
#define FT_VSYNC1	(10L)	// Tvf + Tvp Vertical Front Porch plus Vsync Pulse width
#define FT_VOFFSET	(23L)	// Tvf + Tvp + Tvb Number of non-visible lines (in lines)
#define FT_VCYCLE	(525L)	// Tv Total number of lines (visible and non-visible) (in lines)
#define FT_VSIZE	(480L)	// Tvd Number of visible lines (in lines) - display height
#define FT_HSYNC0	(0L)	// Thf Horizontal Front Porch
#define FT_HSYNC1	(10L)	// Thf + Thp Horizontal Front Porch plus Hsync Pulse width
#define FT_HOFFSET 	(46L)	// Thf + Thp + Thb Length of non-visible part of line (in PCLK cycles)
#define FT_HCYCLE 	(1056L)	// Th Total length of line (visible and non-visible) (in PCLKs)
#define FT_HSIZE	(800L)	// Thd Length of visible part of line (in PCLKs) - display width
#define FT_PCLKPOL 	(1L)	// PCLK polarity (0 = rising edge, 1 = falling edge)
#define FT_SWIZZLE 	(0L)	// Defines the arrangement of the RGB pins of the FT800
#define FT_PCLK		(2L)	// 60MHz / REG_PCLK = PCLK frequency	30 MHz
#define FT_TOUCH_RZTHRESH (1200L)	// touch-sensitivity
#endif


// some pre-definded colors
#define RED		0xff0000UL
#define ORANGE	0xffa500UL
#define GREEN	0x00ff00UL
#define BLUE	0x0000ffUL
#define YELLOW	0xffff00UL
#define PINK	0xff00ffUL
#define PURPLE	0x800080UL
#define WHITE	0xffffffUL
#define BLACK	0x000000UL


#endif /* INCFILE1_H_ */